@@ -8,7 +8,14 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#if defined(QT_NO_STL)
+# define DISABLE_QT_NO_STL
+# undef QT_NO_STL
+#endif
+
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 #ifndef NO_GPSIM
 
 #include "asmparser.h"
@@ -50,8 +57,8 @@ void initialize_ConsoleUI();
 extern void initialize_readline();
 extern void gui_main(void);
 extern void cli_main();
-void gpsim_version() {};
-void quit_gui() {};
+KDE_EXPORT void gpsim_version() {};
+KDE_EXPORT void quit_gui() {};
 
 
 //BEGIN class GpsimProcessor
@@ -788,7 +795,6 @@ void RegisterSet::update()
 //END class RegisterSet
 
 
-
 //BEGIN class RegisterInfo
 RegisterInfo::RegisterInfo( Register * reg )
 {
@@ -815,7 +821,6 @@ RegisterInfo::RegisterInfo( Register * reg )
 			m_type = Invalid;
 			break;
 	}
-		
 	m_name = m_pRegister->baseName();
 }
 
@@ -880,7 +885,11 @@ DebugLine::DebugLine()
 }
 //END class DebugLine
 
-
 #include "gpsimprocessor.moc"
+#endif
 
+// restore QT_NO_STL
+#if defined(DISABLE_QT_NO_STL)
+# undef DISABLE_QT_NO_STL
+# define QT_NO_STL
 #endif
